@@ -1,24 +1,35 @@
 import logging
 import time
+import warnings
 from dataclasses import dataclass
 from itertools import repeat
 from multiprocessing import Pool, cpu_count
 from typing import List, Union
 
+import alphashape
 import numpy as np
 import pandas as pd
-import alphashape
 from scipy.spatial import Delaunay
-from scipy.special import gamma
 from scipy.spatial.qhull import QhullError
+from scipy.special import gamma
 from shapely import geometry
-from shapely.ops import cascaded_union, polygonize, triangulate, unary_union
+from shapely.ops import polygonize, triangulate, unary_union
 from sklearn.cluster import DBSCAN
 
+
 _required_opts = ['PI']
 _logger = logging.getLogger(__name__)
 
 
+# TODO: remove temporary workaround in future
+class AlphashapeFilter(logging.Filter):
+    def filter(self, record: logging.LogRecord) -> bool:
+        return "Likely caused by all points lying in an N-1 space" not in record.getMessage()
+
+
+logging.getLogger().addFilter(AlphashapeFilter())
+
+
 @dataclass
 class FootprintOutput:
     polygon: geometry.MultiPolygon
@@ -83,27 +94,28 @@ def alpha_shape(points: np.ndarray, alpha=1.0):
     edge_points = np.unique(np.concatenate((edge1, edge2, edge3)), axis=0).tolist()
     m = geometry.MultiLineString(edge_points)
     triangles = list(polygonize(m))
-    return cascaded_union(triangles), edge_points
+    return unary_union(triangles), edge_points
 
 
 def alphashape_optm(points: np.ndarray, alpha_ini):
-    points = list(map(tuple, points))
-    hull = alphashape.alphashape(points, alpha_ini)
-    if isinstance(hull, geometry.Polygon):
-        return hull
-    else:
-        alpha = 0.9 * alphashape.optimizealpha(points)
-        hull = alphashape.alphashape(points, alpha)
+    # TODO: remove temporary workaround in future
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore")
+        points = list(map(tuple, points))
+        hull = alphashape.alphashape(points, alpha_ini)
+        if not isinstance(hull, geometry.Polygon):
+            alpha = 0.9 * alphashape.optimizealpha(points)
+            hull = alphashape.alphashape(points, alpha)
         return hull
 
 
-def count_points(pts):
+def count_points(pts: Union[geometry.Point, geometry.MultiPoint]) -> int:
     if pts.is_empty:
         return 0
     elif pts.type == 'Point':
         return 1
     elif pts.type == 'MultiPoint':
-        return len(pts)
+        return len(pts.geoms)
     else:
         raise TypeError
 
