@@ -135,7 +135,9 @@ def train_is(metadata: pd.DataFrame, opts: dict, rotation_adjust=False) -> Model
         bad_instances = mode(model.data.Ybin, axis=1)[0] == 0
         if bad_instances.any():
             logger.info("Adjusting the IS rotation.")
-            model.pilot.Z = adjust_rotation(model.pilot.Z, bad_instances[:, 0])
+            model.pilot.Z, R_theta = adjust_rotation(model.pilot.Z, bad_instances[:, 0])
+            model.pilot.A = R_theta.dot(model.pilot.A)
+            logger.info(f"The space was rotated by {np.round(np.degrees(np.arccos(R_theta[0, 0])), 1)} degrees.")
         else:
             logger.info("It is not possible to adjust the IS rotation because there are no bad instances.")
 
