@@ -26,7 +26,7 @@ def join_polygons(poly):
 
     if poly.is_empty:
         return None
-    poly_gen = (np.array(p.exterior.coords.xy).T[:-1, :] for p in poly)
+    poly_gen = (np.array(p.exterior.coords.xy).T[:-1, :] for p in poly.geoms)
     return reduce(vstack_with_sep, poly_gen)
 
 
